summaryrefslogtreecommitdiffstats
path: root/smb4k/core
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:14:57 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:14:57 -0500
commit07d1a6f299edecf33f2e476e7a26a90e388bd990 (patch)
treed45344c0e919c182fa860cdb159d57dca2100031 /smb4k/core
parent8d3fac90b336884c2a501f192542c9d147a4c985 (diff)
downloadsmb4k-07d1a6f299edecf33f2e476e7a26a90e388bd990.tar.gz
smb4k-07d1a6f299edecf33f2e476e7a26a90e388bd990.zip
Rename KWallet to TDEWallet
Diffstat (limited to 'smb4k/core')
-rw-r--r--smb4k/core/smb4kerror.cpp2
-rw-r--r--smb4k/core/smb4kpasswordhandler.cpp4
-rw-r--r--smb4k/core/smb4kpasswordhandler.h6
3 files changed, 6 insertions, 6 deletions
diff --git a/smb4k/core/smb4kerror.cpp b/smb4k/core/smb4kerror.cpp
index 3fc0ce4..cfbdff5 100644
--- a/smb4k/core/smb4kerror.cpp
+++ b/smb4k/core/smb4kerror.cpp
@@ -89,7 +89,7 @@ void Smb4KError::error( int code, const TQString &text, const TQString &details
}
case ERROR_OPENING_WALLET_FAILED:
{
- KMessageBox::error( 0, i18n( "The wallet \"%1\" could not be opened. KWallet support will be disabled for this session." ).arg( text ) );
+ KMessageBox::error( 0, i18n( "The wallet \"%1\" could not be opened. TDEWallet support will be disabled for this session." ).arg( text ) );
break;
}
diff --git a/smb4k/core/smb4kpasswordhandler.cpp b/smb4k/core/smb4kpasswordhandler.cpp
index b6e2f15..bef5607 100644
--- a/smb4k/core/smb4kpasswordhandler.cpp
+++ b/smb4k/core/smb4kpasswordhandler.cpp
@@ -118,7 +118,7 @@ void Smb4KPasswordHandler::open_close_wallet()
// Do nothing. --- Good luck!
}
- m_wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous );
+ m_wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet(), 0, TDEWallet::Wallet::Synchronous );
if ( m_wallet )
{
@@ -136,7 +136,7 @@ void Smb4KPasswordHandler::open_close_wallet()
}
else
{
- Smb4KError::error( ERROR_OPENING_WALLET_FAILED, KWallet::Wallet::NetworkWallet(), TQString() );
+ Smb4KError::error( ERROR_OPENING_WALLET_FAILED, TDEWallet::Wallet::NetworkWallet(), TQString() );
delete m_wallet;
m_wallet = NULL;
diff --git a/smb4k/core/smb4kpasswordhandler.h b/smb4k/core/smb4kpasswordhandler.h
index 1497569..e73caa7 100644
--- a/smb4k/core/smb4kpasswordhandler.h
+++ b/smb4k/core/smb4kpasswordhandler.h
@@ -236,9 +236,9 @@ class Smb4KPasswordHandler : public TQObject
void convert_old_entries();
/**
* The KWallet object.
*/
- KWallet::Wallet *m_wallet;
+ TDEWallet::Wallet *m_wallet;
/**
* The Smb4KAuthInfo object. For use with the askpass dialog.
@@ -252,7 +252,7 @@ class Smb4KPasswordHandler : public TQObject
/**
* This list holds the authentication data the user supplied if he/she
* does not want to use KWallet.
*/
TQValueList<Smb4KAuthInfo *> m_auth_list;
@@ -236,9 +236,9 @@ class Smb4KPasswordHandler : public TQObject
void convert_old_entries();
/**
- * The KWallet object.
+ * The TDEWallet object.
*/
@@ -252,7 +252,7 @@ class Smb4KPasswordHandler : public TQObject
/**
* This list holds the authentication data the user supplied if he/she
- * does not want to use KWallet.
+ * does not want to use TDEWallet.
*/
TQValueList<Smb4KAuthInfo *> m_auth_list;